aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
l---------[-rwxr-xr-x]cmd/zed/zed.d/data-notify.sh46
-rwxr-xr-xcmd/zed/zed.d/io-notify.sh21
2 files changed, 16 insertions, 51 deletions
diff --git a/cmd/zed/zed.d/data-notify.sh b/cmd/zed/zed.d/data-notify.sh
index 6b65c3815..900873807 100755..120000
--- a/cmd/zed/zed.d/data-notify.sh
+++ b/cmd/zed/zed.d/data-notify.sh
@@ -1,45 +1 @@
-#!/bin/sh
-#
-# Send notification in response to a DATA error.
-#
-# Only one notification per ZED_NOTIFY_INTERVAL_SECS will be sent for a given
-# class/pool combination. This protects against spamming the recipient
-# should multiple events occur together in time for the same pool.
-#
-# Exit codes:
-# 0: notification sent
-# 1: notification failed
-# 2: notification not configured
-# 3: notification suppressed
-# 9: internal error
-
-[ -f "${ZED_ZEDLET_DIR}/zed.rc" ] && . "${ZED_ZEDLET_DIR}/zed.rc"
-. "${ZED_ZEDLET_DIR}/zed-functions.sh"
-
-[ -n "${ZEVENT_POOL}" ] || exit 9
-[ -n "${ZEVENT_SUBCLASS}" ] || exit 9
-
-if [ "${ZEVENT_SUBCLASS}" != "data" ]; then \
- zed_log_err "unsupported event class \"${ZEVENT_SUBCLASS}\""
- exit 9
-fi
-
-zed_rate_limit "${ZEVENT_POOL};${ZEVENT_SUBCLASS};notify" || exit 3
-
-umask 077
-note_subject="ZFS ${ZEVENT_SUBCLASS} error for ${ZEVENT_POOL} on $(hostname)"
-note_pathname="${TMPDIR:="/tmp"}/$(basename -- "$0").${ZEVENT_EID}.$$"
-{
- echo "ZFS has detected a ${ZEVENT_SUBCLASS} error:"
- echo
- echo " eid: ${ZEVENT_EID}"
- echo " class: ${ZEVENT_SUBCLASS}"
- echo " host: $(hostname)"
- echo " time: ${ZEVENT_TIME_STRING}"
- echo " pool: ${ZEVENT_POOL}"
-
-} > "${note_pathname}"
-
-zed_notify "${note_subject}" "${note_pathname}"; rv=$?
-rm -f "${note_pathname}"
-exit "${rv}"
+io-notify.sh \ No newline at end of file
diff --git a/cmd/zed/zed.d/io-notify.sh b/cmd/zed/zed.d/io-notify.sh
index 46b066945..3ce918ad7 100755
--- a/cmd/zed/zed.d/io-notify.sh
+++ b/cmd/zed/zed.d/io-notify.sh
@@ -1,10 +1,10 @@
#!/bin/sh
#
# Send notification in response to a CHECKSUM or IO error.
#
# Only one notification per ZED_NOTIFY_INTERVAL_SECS will be sent for a given
-# class/pool/vdev combination. This protects against spamming the recipient
-# should multiple events occur together in time for the same pool/device.
+# class/pool/[vdev] combination. This protects against spamming the recipient
+# should multiple events occur together in time for the same pool/[vdev].
#
# Exit codes:
# 0: notification sent
@@ -18,16 +18,16 @@
[ -n "${ZEVENT_POOL}" ] || exit 9
[ -n "${ZEVENT_SUBCLASS}" ] || exit 9
-[ -n "${ZEVENT_VDEV_GUID}" ] || exit 9
if [ "${ZEVENT_SUBCLASS}" != "checksum" ] \
+ && [ "${ZEVENT_SUBCLASS}" != "data" ] \
&& [ "${ZEVENT_SUBCLASS}" != "io" ]; then
zed_log_err "unsupported event class \"${ZEVENT_SUBCLASS}\""
exit 9
fi
-zed_rate_limit "${ZEVENT_POOL};${ZEVENT_VDEV_GUID};${ZEVENT_SUBCLASS};notify" \
- || exit 3
+rate_limit_tag="${ZEVENT_POOL};${ZEVENT_VDEV_GUID:-0};${ZEVENT_SUBCLASS};notify"
+zed_rate_limit "${rate_limit_tag}" || exit 3
umask 077
note_subject="ZFS ${ZEVENT_SUBCLASS} error for ${ZEVENT_POOL} on $(hostname)"
@@ -46,6 +46,15 @@ note_pathname="${TMPDIR:="/tmp"}/$(basename -- "$0").${ZEVENT_EID}.$$"
[ -n "${ZEVENT_VDEV_PATH}" ] && echo " vpath: ${ZEVENT_VDEV_PATH}"
[ -n "${ZEVENT_VDEV_GUID}" ] && echo " vguid: ${ZEVENT_VDEV_GUID}"
+ [ -n "${ZEVENT_VDEV_CKSUM_ERRORS}" ] \
+ && echo " cksum: ${ZEVENT_VDEV_CKSUM_ERRORS}"
+
+ [ -n "${ZEVENT_VDEV_READ_ERRORS}" ] \
+ && echo " read: ${ZEVENT_VDEV_READ_ERRORS}"
+
+ [ -n "${ZEVENT_VDEV_WRITE_ERRORS}" ] \
+ && echo " write: ${ZEVENT_VDEV_WRITE_ERRORS}"
+
echo " pool: ${ZEVENT_POOL}"
} > "${note_pathname}"
@@ -1,10 +1,10 @@
#!/bin/sh
#
-# Send notification in response to a CHECKSUM or IO error.
+# Send notification in response to a CHECKSUM, DATA, or IO error.
#
# Only one notification per ZED_NOTIFY_INTERVAL_SECS will be sent for a given